@@ -4,7 +4,7 @@ from bruce.config import Config
 from bruce.page import Page
 from bruce.fonts import get_font
 
-font = get_font(os.path.join(Config.data, 'Vera.ttf'), 64)
+font = get_font(Config.title_font, 64)
 
 BORDER = 64
 
@@ -12,16 +12,18 @@ BORDER = 64
 
 class ImagePage(Page):
     def __init__(self, title, image):
-        self.title = font.render(title, 1, Config.title_fgcolour)
-
-        # get image
-        self.image = pygame.image.load(image).convert()
+        self.title = title
+        self.image = image
 
     def init(self, screen):
-        # resize
+        # init title
+        self.title = font.render(self.title, 1, Config.title_fgcolour)
+
+        # load image and resize
+        image = pygame.image.load(self.image).convert()
         w = screen.get_rect().width - BORDER*2
         h = screen.get_rect().height - BORDER*2
-        imw, imh = self.image.get_rect().size
+        imw, imh = image.get_rect().size
         if imw > w or imh > h:
             if imw > imh:
                 ratio = float(w) / imw
@@ -31,7 +33,7 @@ class ImagePage(Page):
                 ratio = float(h) / imh
                 imh = h
                 imw *= ratio
-        self.image = pygame.transform.scale(self.image, (int(imw), int(imh)))
+        self.image = pygame.transform.scale(image, (int(imw), int(imh)))
 
     def render(self, screen, deltat):
         screen.fill(Config.page_bgcolour)
