@@ -111,6 +111,9 @@ class InterpreterPage(Page):
                         input.startswith('pygame.event.poll()')):
                     pygame.event.set_blocked(KEYUP)
 
+                if input == 'help()':
+                    input = 'print "help() not supported, sorry!"'
+
                 # run the interpreter
                 self.captured_input.append(input)
                 old_stdout = sys.stdout
