@@ -42,10 +42,10 @@ def main(pages, fullscreen=False):
             if event is None: continue
 
             if event.type == KEYDOWN:
-                if event.key == K_PRINT:
-                    pygame.image.save(self.screen, '/tmp/screenshot.bmp')
-                elif event.key == K_ESCAPE:
+                if event.key == K_ESCAPE:
                     return
+                elif event.key == K_p and event.mod & KMOD_CTRL:
+                    pygame.image.save(screen, '/tmp/screenshot.bmp')
                 elif event.key == K_d and event.mod & KMOD_CTRL:
                     # == "next page" when in an interpreter
                     page_position += 1
